﻿using Composite.Data;
using Composite.Data.Hierarchy;
using Composite.Data.Hierarchy.DataAncestorProviders;


namespace C1NorthwindIntegration
{
    /// <summary>
    /// This is a standard implementation of a C1 data interface. See mere information here:    
    /// http://docs.composite.net/C1/Data/Defining-Data-IData-types-in-C1-using-C.aspx/Interface-Attributes
    /// http://docs.composite.net/C1/Data/Defining-Data-IData-types-in-C1-using-C.aspx/Property-Attributes
    /// Generel information here: http://docs.composite.net/C1/Data/Defining-Data-IData-types-in-C1-using-C.aspx
    /// This could be a interface to the generted Product data entity class. Add it again if the classes are regenerated.
    /// </summary>
    [KeyPropertyName("ProductID")]
    [ImmutableTypeId("{11F9C6F7-B9B5-4BAA-B74F-1D240955B662}")]
    [DataScope(DataScopeIdentifier.PublicName)]
    [DataAncestorProvider(typeof(NoAncestorDataAncestorProvider))]
    [NotReferenceableAttribute]
    public interface IProduct : IData
    {
        [StoreFieldType(PhysicalStoreFieldType.Integer)]
        [ImmutableFieldId("{EE5B0160-EBBE-437D-98F9-FFB393CEC282}")]
        int ProductID { get; set; }


        [StoreFieldType(PhysicalStoreFieldType.Integer, IsNullable = true)]
        [ImmutableFieldId("{536D4A75-7F5F-4F6C-BAD5-7A7C450BBE5B}")]
        int? SupplierID { get; set; }


        [StoreFieldType(PhysicalStoreFieldType.String, 40)]
        [ImmutableFieldId("{D75EA67F-AD14-4BAB-8547-6D87002809F0}")]
        string ProductName { get; set; }


        [StoreFieldType(PhysicalStoreFieldType.String, 20)]
        [ImmutableFieldId("{373F327F-9303-4D5E-8206-A5ECA0BEA018}")]
        string QuantityPerUnit { get; set; }


        [StoreFieldType(PhysicalStoreFieldType.Decimal, 10, 2, IsNullable = true)]
        [ImmutableFieldId("{4D6C09F0-DC1B-455C-8D46-1D0751BE5234}")]
        decimal? UnitPrice { get; set; }


        [StoreFieldType(PhysicalStoreFieldType.Integer, IsNullable = true)]
        [ImmutableFieldId("{C07505E1-F226-42B7-9276-961586272757}")]
        short? UnitsInStock { get; set; }


        [StoreFieldType(PhysicalStoreFieldType.Integer, IsNullable = true)]
        [ImmutableFieldId("{BFF14A01-3D52-488F-8A21-C5F2D5521B46}")]
        short? UnitsOnOrder { get; set; }


        [StoreFieldType(PhysicalStoreFieldType.Integer, IsNullable = true)]
        [ImmutableFieldId("{DE3448A2-1820-4F40-A05E-B8624BD0DCCD}")]
        short? ReorderLevel { get; set; }


        [StoreFieldType(PhysicalStoreFieldType.Boolean)]
        [ImmutableFieldId("{E2F09F04-343C-4D1B-A793-CF32891C8697}")]
        bool Discontinued { get; set; }
    }



    /// <summary>
    /// This class handles the DataSourceId part - Unique data key in C1
    /// This could be a super class to the generted Product data entity class. Add it again if the classes are regenerated.
    /// </summary>
    public class ProductBase
    {
        private DataSourceId _dataSourceId = null;


        public DataSourceId DataSourceId
        {
            get
            {
                if (_dataSourceId == null)
                {
                    DataId intDataId = new DataId { Id = ((IProduct)this).ProductID };

                    _dataSourceId = NorthwindDataProvider.DataProviderContextHolder.CreateDataSourceId(intDataId, typeof(IProduct));
                }

                return _dataSourceId;
            }
        }
    }
}
