﻿using System;
using Composite.Data;
using Composite.Data.Hierarchy;
using Composite.Data.Hierarchy.DataAncestorProviders;


namespace C1NorthwindIntegration
{    
    /// <summary>
    /// This is a standard implementation of a C1 data interface    
    /// http://docs.composite.net/C1/Data/Defining-Data-IData-types-in-C1-using-C.aspx/Interface-Attributes
    /// http://docs.composite.net/C1/Data/Defining-Data-IData-types-in-C1-using-C.aspx/Property-Attributes
    /// Generel information here: http://docs.composite.net/C1/Data/Defining-Data-IData-types-in-C1-using-C.aspx
    /// This could be a interface to the generted Supplier data entity class. Add it again if the classes are regenerated.
    /// </summary>
    [KeyPropertyName("SupplierID")]
    [ImmutableTypeId("{717CABAD-6EA7-4451-92C1-B305080E2D8B}")]
    [DataScope(DataScopeIdentifier.PublicName)]
    [DataAncestorProvider(typeof(NoAncestorDataAncestorProvider))]
    [NotReferenceableAttribute]
    public interface ISupplier : IData
    {
        [StoreFieldType(PhysicalStoreFieldType.Integer)]
        [ImmutableFieldId("{FBAEC5FA-9A12-4D5F-B8CD-A1750164DB63}")]
        int SupplierID { get; set; }


        [StoreFieldType(PhysicalStoreFieldType.String, 40)]
        [ImmutableFieldId("{60405037-6ED7-4878-BF9F-4F7F82802986}")]
        string CompanyName { get; set; }


        [StoreFieldType(PhysicalStoreFieldType.String, 30)]
        [ImmutableFieldId("{6C076D79-CC73-4FE4-A971-2F43A00153C9}")]
        string ContactName { get; set; }


        [StoreFieldType(PhysicalStoreFieldType.String, 30)]
        [ImmutableFieldId("{C06EC433-BCF0-4AF1-B5BB-D5BCD4E11C25}")]
        string ContactTitle { get; set; }


        [StoreFieldType(PhysicalStoreFieldType.String, 60)]
        [ImmutableFieldId("{90F4DCD4-879C-4A5B-B90E-CF02E8E80151}")]
        string Address { get; set; }


        [StoreFieldType(PhysicalStoreFieldType.String, 15)]
        [ImmutableFieldId("{FB3664D5-2BAE-4AAE-9338-C252892D3795}")]
        string City { get; set; }


        [StoreFieldType(PhysicalStoreFieldType.String, 15)]
        [ImmutableFieldId("{9081D811-B9EB-4296-94A7-D872B9E71609}")]
        string Region { get; set; }


        [StoreFieldType(PhysicalStoreFieldType.String, 10)]
        [ImmutableFieldId("{BE0BD02D-6065-4800-90B4-65B389792725}")]
        string PostalCode { get; set; }


        [StoreFieldType(PhysicalStoreFieldType.String, 15)]
        [ImmutableFieldId("{E6E7FF7E-9EB9-4382-BC01-1F9F0E1B3229}")]
        string Country { get; set; }


        [StoreFieldType(PhysicalStoreFieldType.String, 24)]
        [ImmutableFieldId("{F008CF27-1B27-4B55-B2C5-591A42DCEC17}")]
        string Phone { get; set; }


        [StoreFieldType(PhysicalStoreFieldType.String, 24)]
        [ImmutableFieldId("{F0553941-D3CB-4A10-931D-0F01755C0378}")]
        string Fax { get; set; }


        [StoreFieldType(PhysicalStoreFieldType.LargeString)]
        [ImmutableFieldId("{A12419B8-082E-4583-A066-C4E253099FAA}")]
        string HomePage { get; set; }
    }



    /// <summary>
    /// This class handles the DataSourceId part - Unique data key in C1
    /// This could be a super class to the generted Supplier data entity class. Add it again if the classes are regenerated.
    /// </summary>
    public class SupplierBase
    {
        private DataSourceId _dataSourceId = null;


        public DataSourceId DataSourceId
        {
            get
            {
                if (_dataSourceId == null)
                {
                    DataId intDataId = new DataId { Id = ((ISupplier)this).SupplierID };

                    _dataSourceId = NorthwindDataProvider.DataProviderContextHolder.CreateDataSourceId(intDataId, typeof(ISupplier));
                }

                return _dataSourceId;
            }
        }
    }
}
